==> azure_mgmt_recoveryservices-0.2.0.crate: azure_mgmt_recoveryservices-0.2.0/README.md <==
# azure_mgmt_recoveryservices crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/recoveryservices/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2022-01`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-2022-01` has 19 operations from 1 API versions: `2022-01-01`. Use crate feature `package-2022-01` to enable. The operations will be in the `package_2022_01` module.
- `package-2021-12` has 19 operations from 1 API versions: `2021-12-01`. Use crate feature `package-2021-12` to enable. The operations will be in the `package_2021_12` module.
- `package-preview-2021-11` has 19 operations from 1 API versions: `2021-11-01-preview`. Use crate feature `package-preview-2021-11` to enable. The operations will be in the `package_preview_2021_11` module.
- `package-2021-08` has 19 operations from 1 API versions: `2021-08-01`. Use crate feature `package-2021-08` to enable. The operations will be in the `package_2021_08` module.
- `package-2021-07` has 19 operations from 1 API versions: `2021-07-01`. Use crate feature `package-2021-07` to enable. The operations will be in the `package_2021_07` module.
- `package-2021-06` has 19 operations from 1 API versions: `2021-06-01`. Use crate feature `package-2021-06` to enable. The operations will be in the `package_2021_06` module.
- `package-2021-04` has 19 operations from 1 API versions: `2021-04-01`. Use crate feature `package-2021-04` to enable. The operations will be in the `package_2021_04` module.
- `package-2021-03` has 19 operations from 1 API versions: `2021-03-01`. Use crate feature `package-2021-03` to enable. The operations will be in the `package_2021_03` module.
- `package-2021-02` has 19 operations from 1 API versions: `2021-02-10`. Use crate feature `package-2021-02` to enable. The operations will be in the `package_2021_02` module.
- `package-2016-06` has 17 operations from 1 API versions: `2016-06-01`. Use crate feature `package-2016-06` to enable. The operations will be in the `package_2016_06` module.
- `package-2020-02` has 19 operations from 1 API versions: `2020-02-02`. Use crate feature `package-2020-02` to enable. The operations will be in the `package_2020_02` module.
- `package-2020-10` has 19 operations from 1 API versions: `2020-10-01`. Use crate feature `package-2020-10` to enable. The operations will be in the `package_2020_10` module.
- `package-2021-01` has 19 operations from 1 API versions: `2021-01-01`. Use crate feature `package-2021-01` to enable. The operations will be in the `package_2021_01` module.

==> azure_mgmt_recoveryservices-0.3.0.crate: azure_mgmt_recoveryservices-0.3.0/README.md <==
# azure_mgmt_recoveryservices crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/recoveryservices/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2022-02`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-2022-02` has 19 operations from 1 API versions: `2022-02-01`. Use crate feature `package-2022-02` to enable. The operations will be in the `package_2022_02` module.
- `package-preview-2022-01` has 20 operations from 1 API versions: `2022-01-31-preview`. Use crate feature `package-preview-2022-01` to enable. The operations will be in the `package_preview_2022_01` module.
- `package-2022-01` has 19 operations from 1 API versions: `2022-01-01`. Use crate feature `package-2022-01` to enable. The operations will be in the `package_2022_01` module.
- `package-2021-12` has 19 operations from 1 API versions: `2021-12-01`. Use crate feature `package-2021-12` to enable. The operations will be in the `package_2021_12` module.
- `package-preview-2021-11` has 19 operations from 1 API versions: `2021-11-01-preview`. Use crate feature `package-preview-2021-11` to enable. The operations will be in the `package_preview_2021_11` module.
- `package-2021-08` has 19 operations from 1 API versions: `2021-08-01`. Use crate feature `package-2021-08` to enable. The operations will be in the `package_2021_08` module.
- `package-2021-07` has 19 operations from 1 API versions: `2021-07-01`. Use crate feature `package-2021-07` to enable. The operations will be in the `package_2021_07` module.
- `package-2021-06` has 19 operations from 1 API versions: `2021-06-01`. Use crate feature `package-2021-06` to enable. The operations will be in the `package_2021_06` module.
- `package-2021-04` has 19 operations from 1 API versions: `2021-04-01`. Use crate feature `package-2021-04` to enable. The operations will be in the `package_2021_04` module.
- `package-2021-03` has 19 operations from 1 API versions: `2021-03-01`. Use crate feature `package-2021-03` to enable. The operations will be in the `package_2021_03` module.
- `package-2021-02` has 19 operations from 1 API versions: `2021-02-10`. Use crate feature `package-2021-02` to enable. The operations will be in the `package_2021_02` module.
- `package-2016-06` has 17 operations from 1 API versions: `2016-06-01`. Use crate feature `package-2016-06` to enable. The operations will be in the `package_2016_06` module.
- `package-2020-02` has 19 operations from 1 API versions: `2020-02-02`. Use crate feature `package-2020-02` to enable. The operations will be in the `package_2020_02` module.
- `package-2020-10` has 19 operations from 1 API versions: `2020-10-01`. Use crate feature `package-2020-10` to enable. The operations will be in the `package_2020_10` module.
- `package-2021-01` has 19 operations from 1 API versions: `2021-01-01`. Use crate feature `package-2021-01` to enable. The operations will be in the `package_2021_01` module.
